@@ -1,6 +1,6 @@
 use santiago::grammar::GrammarRule;
 use santiago::languages::nix::grammar_rules;
-use santiago::languages::nix::lexing_rules;
+use santiago::languages::nix::lexer_rules;
 use santiago::lexer::lex;
 use santiago::lexer::Lexeme;
 use santiago::lexer::LexerRule;
@@ -8,7 +8,7 @@ use santiago::parser::parse;
 use santiago::parser::Forest;
 
 fn main() -> Result<(), String> {
-    let lexing_rules: Vec<LexerRule> = lexing_rules();
+    let lexing_rules: Vec<LexerRule> = lexer_rules();
     let grammar_rules: Vec<GrammarRule> = grammar_rules(&lexing_rules);
 
     let stdin = get_stdin();
